@@ -1,8 +1,7 @@
 import re
 from urllib.parse import urlparse
 
-from urllib3 import util as urllib3_util
-
+from pipenv.patched.pip._vendor.urllib3 import util as urllib3_util
 from pipenv.vendor import parse
 
 requests_session = None  # type: ignore
@@ -13,7 +12,7 @@ def _get_requests_session(max_retries=1):
     global requests_session
     if requests_session is not None:
         return requests_session
-    from pipenv.patched.notpip._vendor import requests
+    from pipenv.patched.pip._vendor import requests
 
     requests_session = requests.Session()
     adapter = requests.adapters.HTTPAdapter(max_retries=max_retries)
